"{ Package: 'jv:vdb' }"

"{ NameSpace: Smalltalk }"

LibraryDefinition subclass:#jv_vdb
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'* Projects & Packages *'
!


!jv_vdb class methodsFor:'description'!

excludedFromPreRequisites
    "list packages which are to be explicitely excluded from the automatic constructed
     prerequisites list. If empty, everything that is found along the inheritance of any of
     my classes is considered to be a prerequisite package."

    ^ #(
    )
!

mandatoryPreRequisites
    "list packages which are mandatory as a prerequisite.
     This are packages containing superclasses of my classes and classes which
     are extended by myself.
     They are mandatory, because we need these packages as a prerequisite for loading and compiling.
     This method is generated automatically,
     by searching along the inheritance chain of all of my classes.
     Please take a look at the #referencedPreRequisites method as well."

    ^ #(
        #'stx:libbasic'    "LibraryDefinition - superclass of jv_vdb"
        #'stx:libview2'    "ApplicationModel - superclass of VDBAbstractApplication"
        #'stx:libwidg2'    "AbstractHierarchicalItem - superclass of VDBFramePresenter"
    )
!

referencedPreRequisites
    "list packages which are a prerequisite, because they contain
     classes which are referenced by my classes.
     These packages are NOT needed as a prerequisite for compiling or loading,
     however, a class from it may be referenced during execution and having it
     unloaded then may lead to a runtime doesNotUnderstand error, unless the caller
     includes explicit checks for the package being present.
     This method is generated automatically,
     by searching all classes (and their packages) which are referenced by my classes.
     Please also take a look at the #mandatoryPreRequisites method"

    ^ #(
        #'jv:libgdbs'    "GDBDebugger - referenced by VDBDebuggerApplication class>>open"
        #'stx:libbasic2'    "List - referenced by VDBAbstractContainer>>initialize"
        #'stx:libtool'    "SmalltalkCodeGeneratorTool - referenced by VDBIconLibrary class>>loadAndCompileImagesFrom:categoryPrefix:"
        #'stx:libtool2'    "MenuEditor - referenced by VDBIconLibrary class>>initialize"
        #'stx:libview'    "Color - referenced by VDBAbstractConsoleApplication>>consoleView"
    )
!

subProjects
    "list packages which are known as subprojects. 
     The generated makefile will enter those and make there as well.
     However: they are not forced to be loaded when a package is loaded; 
     for those, redefine requiredPrerequisites."

    ^ #(
    )
! !

!jv_vdb class methodsFor:'description - contents'!

classNamesAndAttributes
    "lists the classes which are to be included in the project.
     Each entry in the list may be: a single class-name (symbol),
     or an array-literal consisting of class name and attributes.
     Attributes are: #autoload or #<os> where os is one of win32, unix,..."

    ^ #(
        "<className> or (<className> attributes...) in load order"
        VDBAbstractApplication
        VDBIconLibrary
        VDBModelPresenter
        #'jv_vdb'
        VDBAbstractConsoleApplication
        VDBAbstractContainer
        VDBAbstractListApplication
        VDBDebuggerApplication
        VDBEventLogApplication
        VDBFramePresenter
        VDBSourceApplication
        VDBThreadGroupPresenter
        VDBThreadPresenter
        VDBVariablePresenter
        VDBAbstractTreeApplication
        VDBDebuggerConsoleApplication
        VDBInferiorConsoleApplication
        VDBTabbingContainer
        VDBFrameApplication
        VDBStackApplication
    )
!

extensionMethodNames
    "lists the extension methods which are to be included in the project.
     Entries are 2-element array literals, consisting of class-name and selector.
     A correponding method with real names must be present in my concrete subclasses
     if it has extensions."

    ^ #(
    )
! !

!jv_vdb class methodsFor:'description - project information'!

companyName
    "Returns a company string which will appear in <lib>.rc.
     Under win32, this is placed into the dlls file-info"

    ^ 'My Company'
!

description
    "Returns a description string which will appear in nt.def / bc.def"

    ^ 'Class Library'
!

legalCopyright
    "Returns a copyright string which will appear in <lib>.rc.
     Under win32, this is placed into the dlls file-info"

    ^ 'My CopyRight or CopyLeft'
!

productName
    "Returns a product name which will appear in <lib>.rc.
     Under win32, this is placed into the dlls file-info.
     This method is usually redefined in a concrete application definition"

    ^ 'LibraryName'
! !

!jv_vdb class methodsFor:'documentation'!

version_HG
    ^ '$Changeset: <not expanded> $'
! !

